==> charcoal-0.3.2.tar.gz: charcoal-0.3.2/charcoal/classes/filters/EncodingInputFilter.class.php <==
<?
/** 
* ʸ󥳡ǥϥե륿
*
* PHP version 5
*
* @package    filters
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class charcoal_EncodingInputFilter implements charcoal_IFilter
{
	var $_config;
	var $_output_filters;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct()
	{
	}

	/*
	 * ե륿̾
	 */
	public function getFilterName()
	{
		return "Encoding Input Filter";
	}

	/*
	 * ե륿
	 */
	public function init( charcoal_Config $config )
	{
	}

	/*
	 * ե륿Ԥ
	 */
	public function filter( charcoal_Request $request, charcoal_ProcedureContext $context, charcoal_Response $response ){

		log_info( "system",  "EncodingInputFilter¹Ԥޤ", __FILE__, __LINE__ );

		// EncodingConverter
		$conv = charcoal_EncodingConverter::fromString( 'HTML_TO_PHP' );

		// requestȤ򤹤٤ƥ󥳡ǥѴ
		$keys = $request->getKeys();
		foreach( $keys as $key ){
			$value = $request->get( $key );
			if ( is_string($value) ){
				$value = $conv->convertEncoding($value);
				$request->set( $key, $value );
			}
			else if ( is_array($value) ){
				$this->_convertEncodingArray( $value, $conv, 1 );
			}
		}

		log_info( "system",  "EncodingInputFilter¹Ԥλޤ", __FILE__, __LINE__ );

	}

	/*
	 * Υ󥳡ǥѴʺƵ᥽åɡ
	 */
	private function _convertEncodingArray( $ary, EncodingConverter $conv, $level ){

		foreach( $ary as $key => $value ){
			if ( is_string($value) ){
				$value = $conv->convertEncoding($value);
				$ary[ $key ] = $value;
			}
			else if ( is_array($value) ){
				$this->_convertEncodingArray( $value, $conv, $level + 1 );
			}
		}

	}

}

?>

==> charcoal-0.8.0.tar.gz: charcoal-0.8.0/charcoal/classes/filters/EncodingInputFilter.class.php <==
<?php
/** 
* ʸ󥳡ǥϥե륿
*
* PHP version 5
*
* @package    filters
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class EncodingInputFilter extends CharcoalComponent implements IFilter
{
	var $_config;
	var $_output_filters;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct( String $name )
	{
		parent::__construct($name);
	}

	/*
	 * ե륿̾
	 */
	public function getFilterName()
	{
		return "Encoding Input Filter";
	}

	/*
	 * ե륿
	 */
	public function init( Config $config )
	{
	}

	/*
	 * ե륿Ԥ
	 */
	public function filter( IRequest $request, Response $response ){

		log_info( "system",  "EncodingInputFilter¹Ԥޤ", __FILE__, __LINE__ );

		// EncodingConverter
		$conv = EncodingConverter::fromString( 'HTML_TO_PHP' );

		// requestȤ򤹤٤ƥ󥳡ǥѴ
		$keys = $request->getKeys();
		foreach( $keys as $key ){
			$value = $request->get( $key );
			if ( is_string($value) ){
				$value = $conv->convertEncoding($value);
				$request->set( $key, $value );
			}
			else if ( is_array($value) ){
				$this->_convertEncodingArray( $value, $conv, 1 );
			}
		}

		log_info( "system",  "EncodingInputFilter¹Ԥλޤ", __FILE__, __LINE__ );

	}

	/*
	 * Υ󥳡ǥѴʺƵ᥽åɡ
	 */
	private function _convertEncodingArray( $ary, EncodingConverter $conv, $level ){

		foreach( $ary as $key => $value ){
			if ( is_string($value) ){
				$value = $conv->convertEncoding($value);
				$ary[ $key ] = $value;
			}
			else if ( is_array($value) ){
				$this->_convertEncodingArray( $value, $conv, $level + 1 );
			}
		}

	}

}

return __FILE__;
